@@ -64,7 +64,7 @@ void AlarmListView::setColumnsVisible(const QList<bool>& show)
     const bool useName = Preferences::useAlarmName();
     QList<bool> vis{ true, false, true, true, true, !useName };
     const int colCount = useName ? 6 : 5;
-    for (int i = 0, count = std::min(colCount, show.count());  i < count;  ++i)
+    for (int i = 0, count = std::min<int>(colCount, show.count());  i < count;  ++i)
         vis[i] = show[i];
     header()->setSectionHidden(AlarmListModel::TimeColumn,   !vis[0]);
     header()->setSectionHidden(AlarmListModel::TimeToColumn, !vis[1]);
@@ -105,13 +105,24 @@ void AlarmListView::initSections()
     header()->setSectionResizeMode(AlarmListModel::NameColumn, QHeaderView::ResizeToContents);
     header()->setSectionResizeMode(AlarmListModel::TextColumn, QHeaderView::Stretch);
     header()->setStretchLastSection(true);   // necessary to ensure ResizeToContents columns do resize to contents!
-    const int minWidth = viewOptions().fontMetrics.lineSpacing() * 3 / 4;
+    const int minWidth = listViewOptions().fontMetrics.lineSpacing() * 3 / 4;
     header()->setMinimumSectionSize(minWidth);
     const int margin = QApplication::style()->pixelMetric(QStyle::PM_FocusFrameHMargin);
     header()->resizeSection(AlarmListModel::ColourColumn, minWidth);
     header()->resizeSection(AlarmListModel::TypeColumn, AlarmListModel::iconWidth() + 2*margin + 2);
 }
 
+QStyleOptionViewItem AlarmListView::listViewOptions() const
+{
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    return QTreeView::viewOptions();
+#else
+    QStyleOptionViewItem option;
+    initViewItemOption(&option);
+    return option;
+#endif
+}
+
 /******************************************************************************
 * Called when the column order is changed.
 * Save the new order for restoration on program restart.
