@@ -22,11 +22,9 @@
 #include "lib/file.h"
 #include "lib/messagebox.h"
 #include "lib/pushbutton.h"
+#include "akonadiplugin/akonadiplugin.h"
 #include "kalarm_debug.h"
 
-#include <Akonadi/ItemFetchJob>
-#include <Akonadi/ItemFetchScope>
-
 #include <KAboutData>
 #include <KStandardGuiItem>
 #include <KLocalizedString>
@@ -38,9 +36,14 @@
 #if KDEPIM_HAVE_X11
 #include <KWindowInfo>
 #include <netwm.h>
-#include <qx11info_x11.h>
+#if QT_VERSION >= QT_VERSION_CHECK(6, 2, 0)
+#include <QGuiApplication>
+#elif QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <private/qtx11extras_p.h>
+#else
+#include <QX11Info>
+#endif
 #endif
-
 #include <QTextBrowser>
 #include <QScrollBar>
 #include <QCheckBox>
@@ -468,7 +471,7 @@ void MessageWindow::setUpDisplay()
         mHelper->setSilenceButton(mSilenceButton);
     }
 
-    if (mAkonadiItemId() >= 0)
+    if (mEmailId() >= 0  &&  Preferences::useAkonadi())
     {
         // KMail button
         mKMailButton = new PushButton(topWidget);
@@ -1093,18 +1096,15 @@ void MessageWindow::slotOk()
 */
 void MessageWindow::slotShowKMailMessage()
 {
+    AkonadiPlugin* akonadiPlugin = Preferences::akonadiPlugin();
+    if (!akonadiPlugin)
+        return;
     qCDebug(KALARM_LOG) << "MessageWindow::slotShowKMailMessage";
-    if (mAkonadiItemId() < 0)
+    if (mEmailId() < 0)
         return;
-    const QString err = KAlarm::runKMail();
-    if (!err.isNull())
-    {
-        KAMessageBox::sorry(this, err);
-        return;
-    }
     org::kde::kmail::kmail kmail(KMAIL_DBUS_SERVICE, KMAIL_DBUS_PATH, QDBusConnection::sessionBus());
     // Display the message contents
-    QDBusReply<bool> reply = kmail.showMail(mAkonadiItemId());
+    QDBusReply<bool> reply = kmail.showMail(mEmailId());
     bool failed1 = true;
     bool failed2 = true;
     if (!reply.isValid())
@@ -1113,17 +1113,11 @@ void MessageWindow::slotShowKMailMessage()
         failed1 = false;
 
     // Select the mail folder containing the message
-    Akonadi::ItemFetchJob* job = new Akonadi::ItemFetchJob(Akonadi::Item(mAkonadiItemId()));
-    job->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
-    Akonadi::Item::List items;
-    if (job->exec())
-        items = job->items();
-    if (items.isEmpty()  ||  !items.at(0).isValid())
-        qCWarning(KALARM_LOG) << "MessageWindow::slotShowKMailMessage: No parent found for item" << mAkonadiItemId();
+    qint64 colId = akonadiPlugin->getCollectionId(mEmailId());
+    if (colId < 0)
+        qCWarning(KALARM_LOG) << "MessageWindow::slotShowKMailMessage: No parent found for item" << mEmailId();
     else
     {
-        const Akonadi::Item& it = items.at(0);
-        const Akonadi::Collection::Id colId = it.parentCollection().id();
         reply = kmail.selectFolder(QString::number(colId));
         if (!reply.isValid())
             qCCritical(KALARM_LOG) << "kmail 'selectFolder' D-Bus call failed:" << reply.error().message();
@@ -1347,7 +1341,15 @@ FullScreenType haveFullScreenWindow(int screen)
 #if KDEPIM_HAVE_X11
     if (KWindowSystem::isPlatformX11())
     {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 2, 0)
+        using namespace QNativeInterface;
+        auto* x11App = qGuiApp->nativeInterface<QX11Application>();
+        if (!x11App)
+            return type;
+        xcb_connection_t* connection = x11App->connection();
+#else
         xcb_connection_t* connection = QX11Info::connection();
+#endif
         const NETRootInfo rootInfo(connection, NET::ClientList | NET::ActiveWindow, NET::Properties2(), screen);
         const xcb_window_t rootWindow   = rootInfo.rootWindow();
         const xcb_window_t activeWindow = rootInfo.activeWindow();
@@ -1381,7 +1383,15 @@ FullScreenType findFullScreenWindows(const QVector<QRect>& screenRects, QVector<
 #if KDEPIM_HAVE_X11
     if (KWindowSystem::isPlatformX11())
     {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 2, 0)
+        using namespace QNativeInterface;
+        auto* x11App = qGuiApp->nativeInterface<QX11Application>();
+        if (!x11App)
+            return type;
+        xcb_connection_t* connection = x11App->connection();
+#else
         xcb_connection_t* connection = QX11Info::connection();
+#endif
         const NETRootInfo rootInfo(connection, NET::ClientList | NET::ActiveWindow, NET::Properties2());
         const xcb_window_t rootWindow   = rootInfo.rootWindow();
         const xcb_window_t activeWindow = rootInfo.activeWindow();
