@@ -18,6 +18,7 @@
 #include "kamail.h"
 #include "latecancel.h"
 #include "mainwindow.h"
+#include "pluginmanager.h"
 #include "preferences.h"
 #include "recurrenceedit.h"
 #include "resourcescalendar.h"
@@ -536,6 +537,22 @@ MiscPrefTab::MiscPrefTab(StackedScrollGroup* scrollGroup)
     radio->setWhatsThis(wt);
     mXtermCommand->setWhatsThis(wt);
 
+    if (PluginManager::instance()->akonadiPlugin())
+    {
+        // Plugins
+        group = new QGroupBox(i18nc("@title:group", "Plugins"));
+        topLayout()->addWidget(group);
+        vlayout = new QVBoxLayout(group);
+
+        // Akonadi plugin
+        mUseAkonadi = new QCheckBox(i18nc("@option:check", "Enable Akonadi"), group);
+        mUseAkonadi->setToolTip(i18nc("@info:tooltip",
+              "Enable the use of Akonadi to provide features including birthday import, some email functions, and email address book lookup."));
+        mUseAkonadi->setWhatsThis(i18nc("@info:whatsthis",
+              "Enable the use of Akonadi to provide features including birthday import, some email functions, and email address book lookup."));
+        vlayout->addWidget(mUseAkonadi, 0, Qt::AlignLeft);
+    }
+
     topLayout()->addStretch();    // top adjust the widgets
 }
 
@@ -559,6 +576,8 @@ void MiscPrefTab::restore(bool defaults, bool)
     mXtermType->setButton(id);
     mXtermCommand->setEnabled(id == mXtermCount);
     mXtermCommand->setText(id == mXtermCount ? xtermCmd : QString());
+    if (mUseAkonadi)
+        mUseAkonadi->setChecked(Preferences::useAkonadi());
 }
 
 void MiscPrefTab::apply(bool syncToDisc)
@@ -616,6 +635,12 @@ void MiscPrefTab::apply(bool syncToDisc)
     QString text = (xtermID < mXtermCount) ? xtermCommands[xtermID] : mXtermCommand->text();
     if (text != Preferences::cmdXTermCommand())
         Preferences::setCmdXTermCommand(text);
+    if (mUseAkonadi)
+    {
+        b = mUseAkonadi->isChecked();
+        if (b != Preferences::useAkonadi())
+            Preferences::setUseAkonadi(b);
+    }
     PrefsTabBase::apply(syncToDisc);
 }
 
@@ -990,29 +1015,44 @@ EmailPrefTab::EmailPrefTab(StackedScrollGroup* scrollGroup)
     mEmailClient = new ButtonGroup(widget);
     const QString kmailOption = i18nc("@option:radio", "KMail");
     const QString sendmailOption = i18nc("@option:radio", "Sendmail");
-    mKMailButton = new RadioButton(kmailOption);
-    mKMailButton->setMinimumSize(mKMailButton->sizeHint());
-    box->addWidget(mKMailButton);
-    mEmailClient->addButton(mKMailButton, Preferences::kmail);
+    if (PluginManager::instance()->akonadiPlugin())
+    {
+        mKMailButton = new RadioButton(kmailOption);
+        mKMailButton->setMinimumSize(mKMailButton->sizeHint());
+        box->addWidget(mKMailButton);
+        mEmailClient->addButton(mKMailButton, Preferences::kmail);
+    }
     mSendmailButton = new RadioButton(sendmailOption);
     mSendmailButton->setMinimumSize(mSendmailButton->sizeHint());
     box->addWidget(mSendmailButton);
     mEmailClient->addButton(mSendmailButton, Preferences::sendmail);
     connect(mEmailClient, &ButtonGroup::buttonSet, this, &EmailPrefTab::slotEmailClientChanged);
-    widget->setWhatsThis(xi18nc("@info:whatsthis",
-          "<para>Choose how to send email when an email alarm is triggered."
-          "<list><item><interface>%1</interface>: The email is sent automatically via <application>KMail</application>. <application>KMail</application> is started first if necessary.</item>"
-          "<item><interface>%2</interface>: The email is sent automatically. This option will only work if "
-          "your system is configured to use <application>sendmail</application> or a sendmail compatible mail transport agent.</item></list></para>",
-          kmailOption, sendmailOption));
+    const QString sendText = i18nc("@info", "Choose how to send email when an email alarm is triggered.");
+    if (PluginManager::instance()->akonadiPlugin())
+        widget->setWhatsThis(xi18nc("@info:whatsthis",
+            "<para>%1<list><item><interface>%2</interface>: "
+            "The email is sent automatically via <application>KMail</application>.</item>"
+            "<item><interface>%3</interface>: "
+            "The email is sent automatically. This option will only work if your system is "
+            "configured to use <application>sendmail</application> or a sendmail compatible mail transport agent.</item></list></para>",
+                                    sendText, kmailOption, sendmailOption));
+    else
+        widget->setWhatsThis(xi18nc("@info:whatsthis",
+            "<para>%1<list><item><interface>%2</interface>: "
+            "The email is sent automatically. This option will only work if your system is "
+            "configured to use <application>sendmail</application> or a sendmail compatible mail transport agent.</item></list></para>",
+                                    sendText, sendmailOption));
 
-    widget = new QWidget;  // this is to allow left adjustment
-    topLayout()->addWidget(widget);
-    box = new QHBoxLayout(widget);
-    mEmailCopyToKMail = new QCheckBox(xi18nc("@option:check", "Copy sent emails into <application>KMail</application>'s <resource>%1</resource> folder", KAMail::i18n_sent_mail()));
-    mEmailCopyToKMail->setWhatsThis(xi18nc("@info:whatsthis", "After sending an email, store a copy in <application>KMail</application>'s <resource>%1</resource> folder", KAMail::i18n_sent_mail()));
-    box->addWidget(mEmailCopyToKMail);
-    box->addStretch();    // left adjust the controls
+    if (PluginManager::instance()->akonadiPlugin())
+    {
+        widget = new QWidget;  // this is to allow left adjustment
+        topLayout()->addWidget(widget);
+        box = new QHBoxLayout(widget);
+        mEmailCopyToKMail = new QCheckBox(xi18nc("@option:check", "Copy sent emails into <application>KMail</application>'s <resource>%1</resource> folder", KAMail::i18n_sent_mail()));
+        mEmailCopyToKMail->setWhatsThis(xi18nc("@info:whatsthis", "After sending an email, store a copy in <application>KMail</application>'s <resource>%1</resource> folder", KAMail::i18n_sent_mail()));
+        box->addWidget(mEmailCopyToKMail);
+        box->addStretch();    // left adjust the controls
+    }
 
     widget = new QWidget;   // this is to allow left adjustment
     topLayout()->addWidget(widget);
@@ -1049,11 +1089,11 @@ EmailPrefTab::EmailPrefTab(StackedScrollGroup* scrollGroup)
     mFromAddrButton->setFocusWidget(mEmailAddress);
     grid->addWidget(mEmailAddress, 1, 2);
 
-    // 'From' email address to be taken from System Settings
-    mFromCCentreButton = new RadioButton(xi18nc("@option:radio", "Use default address from <application>KMail</application> or System Settings"), group);
+    // 'From' email address to be taken from KMail
+    mFromCCentreButton = new RadioButton(xi18nc("@option:radio", "Use default <application>KMail</application> identity"), group);
     mFromAddressGroup->addButton(mFromCCentreButton, Preferences::MAIL_FROM_SYS_SETTINGS);
     mFromCCentreButton->setWhatsThis(
-          xi18nc("@info:whatsthis", "Check to use the default email address set in <application>KMail</application> or KDE System Settings, to identify you as the sender when sending email alarms."));
+          xi18nc("@info:whatsthis", "Check to use the default email address set in <application>KMail</application>, to identify you as the sender when sending email alarms."));
     grid->addWidget(mFromCCentreButton, 2, 1, 1, 2, Qt::AlignLeft);
 
     // 'From' email address to be picked from KMail's identities when the email alarm is configured
@@ -1085,11 +1125,11 @@ EmailPrefTab::EmailPrefTab(StackedScrollGroup* scrollGroup)
     mBccAddrButton->setFocusWidget(mEmailBccAddress);
     grid->addWidget(mEmailBccAddress, 5, 2);
 
-    // 'Bcc' email address to be taken from System Settings
-    mBccCCentreButton = new RadioButton(xi18nc("@option:radio", "Use default address from <application>KMail</application> or System Settings"), group);
+    // 'Bcc' email address to be taken from KMail
+    mBccCCentreButton = new RadioButton(xi18nc("@option:radio", "Use default <application>KMail</application> identity"), group);
     mBccAddressGroup->addButton(mBccCCentreButton, Preferences::MAIL_FROM_SYS_SETTINGS);
     mBccCCentreButton->setWhatsThis(
-          xi18nc("@info:whatsthis", "Check to use the default email address set in <application>KMail</application> or KDE System Settings, for blind copying email alarms to yourself."));
+          xi18nc("@info:whatsthis", "Check to use the default email address set in <application>KMail</application>, for blind copying email alarms to yourself."));
     grid->addWidget(mBccCCentreButton, 6, 1, 1, 2, Qt::AlignLeft);
 
     topLayout()->addStretch();    // top adjust the widgets
@@ -1098,7 +1138,8 @@ EmailPrefTab::EmailPrefTab(StackedScrollGroup* scrollGroup)
 void EmailPrefTab::restore(bool defaults, bool)
 {
     mEmailClient->setButton(Preferences::emailClient());
-    mEmailCopyToKMail->setChecked(Preferences::emailCopyToKMail());
+    if (mEmailCopyToKMail)
+        mEmailCopyToKMail->setChecked(Preferences::emailCopyToKMail());
     setEmailAddress(Preferences::emailFrom(), Preferences::emailAddress());
     setEmailBccAddress((Preferences::emailBccFrom() == Preferences::MAIL_FROM_SYS_SETTINGS), Preferences::emailBccAddress());
     mEmailQueuedNotify->setChecked(Preferences::emailQueuedNotify());
@@ -1111,15 +1152,18 @@ void EmailPrefTab::apply(bool syncToDisc)
     const int client = mEmailClient->selectedId();
     if (client >= 0  &&  static_cast<Preferences::MailClient>(client) != Preferences::emailClient())
         Preferences::setEmailClient(static_cast<Preferences::MailClient>(client));
-    bool b = mEmailCopyToKMail->isChecked();
-    if (b != Preferences::emailCopyToKMail())
-        Preferences::setEmailCopyToKMail(b);
+    if (mEmailCopyToKMail)
+    {
+        bool b = mEmailCopyToKMail->isChecked();
+        if (b != Preferences::emailCopyToKMail())
+            Preferences::setEmailCopyToKMail(b);
+    }
     int from = mFromAddressGroup->selectedId();
     QString text = mEmailAddress->text().trimmed();
     if ((from >= 0  &&  static_cast<Preferences::MailFrom>(from) != Preferences::emailFrom())
     ||  text != Preferences::emailAddress())
         Preferences::setEmailAddress(static_cast<Preferences::MailFrom>(from), text);
-    b = (mBccAddressGroup->checkedButton() == mBccCCentreButton);
+    bool b = (mBccAddressGroup->checkedButton() == mBccCCentreButton);
     Preferences::MailFrom bfrom = b ? Preferences::MAIL_FROM_SYS_SETTINGS : Preferences::MAIL_FROM_ADDR;;
     text = mEmailBccAddress->text().trimmed();
     if (bfrom != Preferences::emailBccFrom()  ||  text != Preferences::emailBccAddress())
@@ -1130,6 +1174,21 @@ void EmailPrefTab::apply(bool syncToDisc)
     PrefsTabBase::apply(syncToDisc);
 }
 
+void EmailPrefTab::showEvent(QShowEvent* e)
+{
+    bool enable = Preferences::useAkonadiIfAvailable();
+    if (mKMailButton)
+    {
+        mKMailButton->setEnabled(enable);
+        if (!enable)
+            mEmailClient->setButton(Preferences::sendmail);
+    }
+    if (mEmailCopyToKMail)
+        mEmailCopyToKMail->setEnabled(enable);
+
+    PrefsTabBase::showEvent(e);
+}
+
 void EmailPrefTab::setEmailAddress(Preferences::MailFrom from, const QString& address)
 {
     mFromAddressGroup->setButton(from);
@@ -1144,7 +1203,8 @@ void EmailPrefTab::setEmailBccAddress(bool useSystemSettings, const QString& add
 
 void EmailPrefTab::slotEmailClientChanged(QAbstractButton* button)
 {
-    mEmailCopyToKMail->setEnabled(button == mSendmailButton);
+    if (mEmailCopyToKMail)
+        mEmailCopyToKMail->setEnabled(button == mSendmailButton  &&  Preferences::useAkonadiIfAvailable());
 }
 
 void EmailPrefTab::slotFromAddrChanged(QAbstractButton* button)
@@ -1178,18 +1238,18 @@ QString EmailPrefTab::validate()
 
 QString EmailPrefTab::validateAddr(ButtonGroup* group, QLineEdit* addr, const QString& msg)
 {
-    QString errmsg = xi18nc("@info", "<para>%1</para><para>Are you sure you want to save your changes?</para>", msg);
+    QString errmsg = i18nc("@info", "Are you sure you want to save your changes?");
     switch (group->selectedId())
     {
         case Preferences::MAIL_FROM_SYS_SETTINGS:
             if (!KAMail::controlCentreAddress().isEmpty())
                 return {};
-            errmsg = xi18nc("@info", "No default email address is currently set in <application>KMail</application> or KDE System Settings. %1", errmsg);
+            errmsg = xi18nc("@info", "<para>No default email address is currently set in <application>KMail</application>.</para><para>%1</para><para>%2</para>", msg, errmsg);
             break;
         case Preferences::MAIL_FROM_KMAIL:
             if (Identities::identitiesExist())
                 return {};
-            errmsg = xi18nc("@info", "No <application>KMail</application> identities currently exist. %1", errmsg);
+            errmsg = xi18nc("@info", "<para>No <application>KMail</application> identities currently exist.</para><para>%1</para><para>%2</para>", msg, errmsg);
             break;
         case Preferences::MAIL_FROM_ADDR:
             if (!addr->text().trimmed().isEmpty())
