@@ -19,6 +19,8 @@ public:
 
 protected Q_SLOTS:
     void initSections() override;
+private:
+    QStyleOptionViewItem listViewOptions() const;
 };
 
 
@@ -31,5 +33,4 @@ public:
     void edit(KAEvent&, EventListView*) override;
 };
 
-
 // vim: et sw=4:
